@@ -30,7 +30,8 @@ class py1337x():
     
     #: Top 100 torrents
     def top(self, category=None):
-        url = f"{self.baseUrl}/top-100{'-'+category.lower() if category else ''}"
+        category = 'applications' if category and category.lower() == 'apps' else 'television' if category and category.lower() == 'tv' else category.lower() if category else None
+        url = f"{self.baseUrl}/top-100{'-'+category if category else ''}"
         
         response = requests.get(url, headers=self.headers)
         return parser.torrentParser(response)
